@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 import os
 import sys
 import unittest
@@ -45,6 +44,7 @@ class CambTest(unittest.TestCase):
         pars.z_outputs = pars.z_outputs
         pars.z_outputs = []
         pars.z_outputs = None
+        # noinspection PyTypeChecker
         self.assertFalse(len(pars.z_outputs))
         with self.assertRaises(TypeError):
             pars.DarkEnergy = initialpower.InitialPowerLaw()
@@ -219,6 +219,11 @@ class CambTest(unittest.TestCase):
         self.assertEqual(pars.nu_mass_eigenstates, 2)
         self.assertAlmostEqual(pars.nu_mass_fractions[0], 0.915197, places=4)
 
+        pars = camb.CAMBparams()
+        pars.set_cosmology(H0=68.5, ombh2=0.022, omch2=0.122, YHe=0.2453, mnu=0.07, omk=0, zrei=zre)
+        results = camb.get_background(pars)
+        self.assertEqual(results.Params.Reion.redshift, zre)
+
     def testEvolution(self):
         redshifts = [0.4, 31.5]
         pars = camb.set_params(H0=67.5, ombh2=0.022, omch2=0.122, As=2e-9, ns=0.95,
@@ -499,13 +504,14 @@ class CambTest(unittest.TestCase):
         pars.InitPower.set_params(As=2.1e-9, ns=0.9)
         self.assertAlmostEqual(pars2.scalar_power(1.1), pars.scalar_power(1.1), delta=As * 1e-4)
 
-        def PK(k, As, ns):
-            return As * (k / 0.05) ** (ns - 1) * (1 + 0.1 * np.sin(10 * k))
+        def PK(k, A, n):
+            return A * (k / 0.05) ** (n - 1) * (1 + 0.1 * np.sin(10 * k))
 
         pars.set_initial_power_function(PK, args=(3e-9, 0.95))
         P = pars.scalar_power(ks)
         np.testing.assert_almost_equal(P, PK(ks, 3e-9, 0.95), decimal=4)
 
+    # noinspection PyTypeChecker
     def testSources(self):
         from camb.sources import GaussianSourceWindow, SplinedSourceWindow
         pars = camb.CAMBparams()
